@@ -1,4 +1,4 @@
-# $Header: /home/fergal/my/cvs/Exporter-Easy/lib/Exporter/Easiest.pm,v 1.2 2003/02/12 12:18:44 fergal Exp $
+# $Header: /home/fergal/my/cvs/Exporter-Easy/lib/Exporter/Easiest.pm,v 1.4 2003/02/13 02:18:24 fergal Exp $
 # Be lean.
 use strict;
 no strict 'refs';
@@ -34,7 +34,7 @@ sub parse_spec
 	{
 		my $new_key = shift @spec;
 		my $arrow = shift @spec;
-		die "Expected => not '$arrow' after $new_key" unless ($arrow eq '=>');
+		die "Expected '=>' not '$arrow' after $new_key" unless ($arrow eq '=>');
 
 		if ($new_key =~ s/^://)
 		{
@@ -46,7 +46,12 @@ sub parse_spec
 		else
 		{
 			$key = $new_key;
-			$spec{$key} = suck_list(\@spec);
+
+			# VARS and ISA should aren't necessarily a list
+
+			$spec{$key} = ($key =~ /^(VARS|ISA)$/ and $spec[0] =~ /^\d+$/) ?
+				shift @spec :
+				suck_list(\@spec);
 		}
 	}
 
@@ -106,13 +111,14 @@ In other files which wish to use YourModule:
 The Exporter::Easiest module is a wrapper around Exporter::Easy. It allows
 you to pass the arguments into Exporter::Easy without all those tiresome []s
 and qw()s. You pass arguments in as a string or an array of strings. You no
-longer need to brack things or take references. If want, you can also leave
+longer need to bracket lists or take references. If want, you can also leave
 out the TAGS key and just put tag definitions along with the other keys.
 
-The important thing to remember is that tags should be preceded by :
-everywhere, including to the left of the =>, otherwise it'll get confused.
-Don't worry I haven't done something horribly pythonesque, whitespace is not
-significant.
+The important thing to remember is that tags should be preceded by ':'
+everywhere, including to the left of the '=>', otherwise it'll get confused.
+And don't worry I haven't done something horribly pythonesque, whitespace is
+not significant, all the parsing logic revolves around the use of ':'s and
+'=>'s
 
 =head1 SEE ALSO
 
